pub struct StaticTracker<DataProvider> {
pub size: usize,
pub counter: usize,
/* private fields */
}Expand description
Keeps track of the SCALE encoded byte length of the snapshot’s voters or targets.
The tracker calculates the bytes used based on static rules, without requiring any actual encoding or extra allocations.
Fields
size: usizecounter: usizeImplementations
Sourceimpl<DataProvider> StaticTracker<DataProvider>where
DataProvider: ElectionDataProvider,
impl<DataProvider> StaticTracker<DataProvider>where
DataProvider: ElectionDataProvider,
Sourcepub fn try_register_voter(
&mut self,
voter: &VoterOf<DataProvider>,
bounds: &DataProviderBounds,
) -> Result<(), ()>
pub fn try_register_voter( &mut self, voter: &VoterOf<DataProvider>, bounds: &DataProviderBounds, ) -> Result<(), ()>
Tries to register a new voter.
If the new voter exhausts the provided bounds, return an error. Otherwise, the internal state of the tracker is updated with the new registered voter.
Sourcepub fn try_register_target(
&mut self,
target: DataProvider::AccountId,
bounds: &DataProviderBounds,
) -> Result<(), ()>
pub fn try_register_target( &mut self, target: DataProvider::AccountId, bounds: &DataProviderBounds, ) -> Result<(), ()>
Tries to register a new target.
If the new target exhausts the provided bounds, return an error. Otherwise, the internal state of the tracker is updated with the new registered target.